@@ -96,7 +96,7 @@ pub struct LdtkJsonRoot {
     pub identifier_style: IdentifierStyle,
 
     /// "Image export" option when saving project. Possible values: `None`, `OneImagePerLayer`,
-    /// `OneImagePerLevel`
+    /// `OneImagePerLevel`, `LayersAndLevels`
     #[serde(rename = "imageExportMode")]
     pub image_export_mode: ImageExportMode,
 
@@ -127,6 +127,11 @@ pub struct LdtkJsonRoot {
     #[serde(rename = "pngFilePattern")]
     pub png_file_pattern: Option<String>,
 
+    /// If TRUE, a very simplified will be generated on saving, for quicker & easier engine
+    /// integration.
+    #[serde(rename = "simplifiedExport")]
+    pub simplified_export: bool,
+
     /// This optional description is used by LDtk Samples to show up some informations and
     /// instructions.
     #[serde(rename = "tutorialDesc")]
@@ -797,9 +802,10 @@ pub struct TilesetDefinition {
     #[serde(rename = "pxWid")]
     pub px_wid: i64,
 
-    /// Path to the source file, relative to the current project JSON file
+    /// Path to the source file, relative to the current project JSON file<br/>  It can be null
+    /// if no image was provided, or when using an embed atlas.
     #[serde(rename = "relPath")]
-    pub rel_path: String,
+    pub rel_path: Option<String>,
 
     /// Array of group of tiles selections, only meant to be used in the editor
     #[serde(rename = "savedSelections")]
@@ -1681,9 +1687,12 @@ pub enum IdentifierStyle {
 }
 
 /// "Image export" option when saving project. Possible values: `None`, `OneImagePerLayer`,
-/// `OneImagePerLevel`
+/// `OneImagePerLevel`, `LayersAndLevels`
 #[derive(Clone, Debug, Serialize, Deserialize)]
 pub enum ImageExportMode {
+    #[serde(rename = "LayersAndLevels")]
+    LayersAndLevels,
+
     #[serde(rename = "None")]
     None,
 
